######################################
##### Utilities for Otter-Grader #####
######################################

import os
import pandas as pd

def list_files(path):
	"""Returns a list of all non-hidden files in a directory"""
	return [file for file in os.listdir(path) if os.path.isfile(os.path.join(path, file)) and file[0] != "."]

def merge_csv(dataframes, output_path):
	"""Merges dataframes returned by Docker containers"""
	final_dataframe = pd.concat(dataframes, axis=0, join='inner').sort_index()
	return final_dataframe



import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	name = "otter-grader",
	version = "0.1.14",
	author = "UC Berkeley Division of Data Science and Information",
	author_email = "cpyles@berkeley.edu",
	description = "Jupyter Notebook Autograder",
	long_description = long_description,
	long_description_content_type = "text/markdown",
	url = "https://github.com/ucbds-infra/otter-grader",
	license = "BSD-3-Clause",
	packages = setuptools.find_packages(),
	classifiers = [
		"Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
	],
	install_requires=[
		"nb2pdf==0.1.1",
		"tornado==5.1.1"
	],
	scripts=["bin/otter"]
)